/* Copyright (C) 2009,2010 ThomasKlosa
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

/**
 * @file
 * @ingroup gBoardTest
 */
 


#define HLOG_DEBUG

#include <stdint.h>
#include <stdbool.h>
#include <stdio.h>
#include <util/delay.h>
#include <avr/io.h> 
#include <avr/interrupt.h>   
#include <string.h>

#include "expal_board.h"
#include "hlog_extmem.h"
#include "usb-fifo.h"
#include "keys.h"
#include "hlog_lcd.h"

#include "display.h"
#include "fontlist.h"
#include "term.h"
#include "power.h"
#include "async32khz.h"

#include "adc.h"

// ************************************************************************
int main(){

	uint8_t lcdChar, kc;
	char k[21];
	
	lcdChar=0;
	
	hl_pwr_InitBoard();
	hl_pwr_InitPwrMan();
	hl_Key_Init();
	hl_asyn_init();

	sei(); 				// Let loose the interrupts!

	for(kc=0; kc<20; kc++){
		k[kc]=0x20;
	}
	k[20]=0;

	// Init USB as std. out and in
	USBInit();
	USB_assign_stdio ();
	printf_P(PSTR("HLOG Startup\r\n"));

	/* init ADC */
	hl_adc_init ();

	// Init LCD

	HL_LCD_Init();
	
	_delay_ms(200);
	hl_lcd_clear ();
	_delay_ms (200);



	hl_lcd_set_font (&font_12x16);

	term_init ();
	term_strprint_P (PSTR("Hello Planet!\r\n"));
	term_strprint_P (PSTR(" "));
	_delay_ms (1000);

	hl_lcd_set_font (&font_8x8);
	term_strprint_P (PSTR("OSM rules!\r\n"));
	_delay_ms (1000);

	hl_lcd_set_font (&font_5x8);
	term_strprint_P (PSTR("    no animals were harmed."));
	_delay_ms (1000);

	hl_lcd_set_font (&font_8x8);


	/* power up 3.3 */
	HL_PWR_VCC33_PORT |= _BV(HL_PWR_VCC33);


	/* start ADC */
	hl_adc_select (adc_chan0);
	hl_adc_start ();





	// *****************************************************
	while(1){
		char s[16];
		lcdChar++;
		uint8_t wSrc;

		// Counter in upper left corner (live sign)
  		sprintf_P(s, PSTR("%02x"), lcdChar);
		hl_lcd_drawstr (28*8, 1, s);

		/* Display BatVoltage */
		uint16_t vbat = hl_pwr_GetBatVoltage();
		sprintf_P(s,PSTR("Vbat: %1d.%02d"),
			    vbat>>8,((vbat & 0xFF)*100)>>8);
		hl_lcd_drawstr (4*8, 36, s);
		
		// Display Key Entry Line
		hlGetKey( &(k[19]) );
		if((k[19]) != 0){
			hl_lcd_drawstr (16, 45, k);
			for(kc=0; kc<19; kc++){
				k[kc]= k[kc+1];
			}
			k[19]=0;			
		}


		do{
			wSrc = hl_pwr_EnterSleep();
		}while ( (wSrc & HL_PWR_WAKE_BY_SYS_TMR) != 0 );
	}

	return 0;
}
