/* Copyright (C) 2009,2010 ThomasKlosa, Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#define HLOG_DEBUG

#include <stdint.h>
#include <stdbool.h>
#include <stdio.h>
#include <util/delay.h>
#include <avr/io.h> 
#include <avr/interrupt.h>   
#include <string.h>
#include <ctype.h>

#include "expal_board.h"
#include "hlog_extmem.h"
#include "usb-fifo.h"
#include "keys.h"
#include "hlog_lcd.h"

#include "display.h"
#include "fontlist.h"
#include "term.h"
#include "power.h"

#include "adc.h"
#include "rtc.h"
#include "usarts.h"
#include "fifo.h"
#include "nmea_hl.h"

fifo_item_t mod_rxfifobuf[64];
fifo_item_t ext_rxfifobuf[64];
nmea_parser_t * modparser;

void hl_display_sats (nmea_parser_t * p)
{
  uint8_t i;
  hl_lcd_set_font (&font_4x6);
  hl_lcd_set_rectangle (0,0, 5*4+100, 12*4, op_clear);

  for (i = 0; i<12; i+=2) {
    nmea_sat_t * sat0 = nmea_get_satellite (p, i);
    nmea_sat_t * sat1 = nmea_get_satellite (p, i+1);
    char s[6];
    if (sat0 || sat1) {
      if (sat0 && sat1)
	sprintf_P (s, PSTR("%02hu/%02hu"), sat0->id, sat1->id);
      else if (sat0)
	sprintf_P (s, PSTR("%02hu   "), sat0->id);
      else /*if (sat1)/*TRUE here*/
	sprintf_P (s, PSTR("   %02hu"), sat1->id);
      hl_lcd_drawstr (0, 4*i+1, s);
      if (sat0 && sat0->snr != 0xFF)
	hl_lcd_set_rectangle (5*4+1,4*i, 5*4+1 + sat0->snr, 4*i+3, op_set);
      if (sat1 && sat1->snr != 0xFF)
	hl_lcd_set_rectangle (5*4+1,4*i+4, 5*4+1 + sat1->snr, 4*i+4+3, op_set);
    }
  }
  hl_lcd_set_font (&font_8x8);
}

/* init USART (mod) */
static usart_control_t * init_modgps (void)
{
  usart_control_t * modgps = usart_init (usart_mod, NULL, 0,
					 mod_rxfifobuf, sizeof(mod_rxfifobuf));
  usart_set_baudrate (modgps, 9600);
  return modgps;
}

/* init USART (ext) */
static usart_control_t * init_extgps (void)
{
  usart_control_t * extgps = usart_init (usart_ext, NULL, 0,
					 ext_rxfifobuf, sizeof(ext_rxfifobuf));
  usart_set_baudrate (extgps, 4800);
  return extgps;
}

// ************************************************************************
int main(){

	uint8_t lcdChar, kc;
	char k[21];
	usart_control_t * modgps, * extgps;

	lcdChar=0;
	// Set system lines in a defined, not floating state
	hl_pwr_InitBoard ();
	hl_pwr_InitPwrMan ();

	hl_rtc_osc_init ();

	for(kc=0; kc<20; kc++){
		k[kc]=' ';
	}
	k[20]='\0';

	// Init USB as std. out and in
	USBInit();
	USB_assign_stdio ();
	printf_P(PSTR("HLOG Startup\r\n"));

	/* init ADC */
	hl_adc_init ();

	// Init LCD

	HL_LCD_Init();
	
	_delay_ms(200);
	hl_lcd_clear ();
	_delay_ms (200);



	/* the delays ensure that the async oscillator has started up
	 *
	 * WHEN REMOVING THE DELAYS ENSURE AT LEAST 1 SECOND
	 * BETWEEN hl_rtc_osc_init() AND hl_rtc_init() !!!
	 */
	hl_lcd_set_font (&font_12x16);

	term_init ();
	term_strprint_P (PSTR("Hello Planet!\r\n"));
	term_strprint_P (PSTR(" "));
	_delay_ms (1000);

	hl_rtc_init ();
	
	hl_lcd_set_font (&font_8x8);
	term_strprint_P (PSTR("OSM rules!\r\n"));
	hl_sleep_for_tick (1000);

	hl_lcd_set_font (&font_5x8);
	term_strprint_P (PSTR("    no animals were harmed.\r\n"));
	hl_sleep_for_tick (1000);

	hl_lcd_set_font (&font_8x8);


	/* start ADC */
	hl_adc_select (adc_chan0);
	hl_adc_start ();

	modgps = init_modgps ();
	extgps = init_extgps ();

	modparser = new_nmea_parser ();

	usart_enable (modgps);
	usart_enable (extgps);

	/* power up 3.3 */
	HL_PWR_VCC33_PORT |= _BV(HL_PWR_VCC33);

	// *****************************************************
	while(1){
		char s[16];
		hl_time_t now = hl_get_current_time ();

		// time in upper left corner (live sign)
		lcdChar++;
  		sprintf_P(s, PSTR("%08lX"), now.seconds);
		hl_lcd_drawstr (22*8, 1, s);
		sprintf_P(s, PSTR("%04X"), now.ticks);
		hl_lcd_drawstr (22*8, 10, s);

		hlKeyTmTick();
		hl_pwr_fast (NULL);

		if((lcdChar & 0x0f)== 0x0f){
		
		  // runs with 1/16 of main loop
		
		  /* display voltage of battery */
		  uint16_t vbat = hl_adc_convert(hl_adc_result ());
		  sprintf_P(s,PSTR("Vbat: %1d.%02d"),
			    vbat>>8,((vbat & 0xFF)*100)>>8);
		  hl_lcd_drawstr (16*8, 36, s);

		  if ((vbat >> 8) < 3) {
		    /* power-off when supply voltage is too low */
		    if (modgps) {
		      usart_disable (modgps);
		      usart_poweroff (modgps);
		      modgps = NULL;
		      /* power down 3.3 */
		      HL_PWR_VCC33_PORT &= ~_BV(HL_PWR_VCC33);
		    }
		    if (extgps) {
		      usart_disable (extgps);
		      usart_poweroff (modgps);
		    }
		  } else if ((vbat >> 8) > 3 || (vbat & 0xFF) >= 60) {
		    /* power-on again when supply voltage rises
		     * (e.g. after battery change when USB supplies
		     * power)
		     */
		    if (!modgps) {
		      HL_PWR_VCC33_PORT |= _BV(HL_PWR_VCC33);
		      modgps = init_modgps ();
		      usart_enable (modgps);
		    }
		    if (!extgps) {
		      extgps = init_extgps ();
		      usart_enable (extgps);
		    }
		  }

		  // Display Key Entry Line
		  hlGetKey( &(k[19]) );
		  if((k[19]) != 0){
		    hl_lcd_drawstr (16, 45, k);
		    for(kc=0; kc<19; kc++){
		      k[kc]= k[kc+1];
		    }
		    k[19]=0;			
		  }
		}
		hl_sleep_for_tick (19);

		while (modgps && usart_can_recv (modgps)) {
		  nmea_line_status_t stat;
		  uint8_t b = usart_recv (modgps);
		  if (0) {
		    if (b == '\n') term_print ('\r');
		    term_print (b);
		  }
		  if (1) {
		    if (b == '\n')
		      putc ('\r', stdout);
		    putc ((isprint(b) || b == '\n' || b == '\r') ? b : '_' , stdout);
		  }
		  if (modparser) {
		    char buf[64];
		    int sz;
		    stat = nmea_recvd (modparser, b);
		    switch (stat) {
		    case NMEA_LINE_FIX:
		      sz = nmea_format_position (buf, sizeof(buf)-1, modparser);
		      buf[sizeof(buf)-1] = '\0';
		      hl_lcd_drawstr (0,48, buf);
		      break;
		    case NMEA_LINE_SAT:
		      hl_display_sats (modparser);
		      break;
		    default: /* don't care */
		      break;
		    }
		  }
		}
		while (extgps && usart_can_recv (extgps)) {
		  uint8_t b = usart_recv (extgps);
		  if (1) {
		    if (b == '\n') term_print ('\r');
		    term_print (b);
		  }
		  if (1) {
		    if (b == '\n')
		      putc ('\r', stdout);
		    putc ((isprint(b) || b == '\n' || b == '\r') ? b : '_' , stdout);
		  }
		}
	}

	return 0;
}
