/// This file has been prepared for Doxygen automatic documentation generation.
/*! \file *********************************************************************
 *
 * \brief  DB101 main demo application.
 *
 * \par Application note:
 *      AVR482: DB101 Software
 *
 * \par Documentation
 *      For comprehensive code documentation, supported compilers, compiler
 *      settings and supported devices see readme.html
 *
 * \author
 *      Atmel Corporation: http://www.atmel.com \n
 *      Support email: avr@atmel.com
 *
 * $Revision: 2347 $
 * $Date: 2007-09-11 00:18:39 -0600 (ti, 11 sep 2007) $
 * $URL: http://revisor.norway.atmel.com/AppsAVR8/avr482_db101_software_users_guide/tags/release_A_code_20070917/IAR/production_demo_rev_A/main.c $
 *
 * Copyright (c) 2006, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

#include <cal.h>
#include <common.h>

#include <lcd_lib.h>
#include <s6b1713_driver.h>
#include <joystick_driver.h>
#include <fifo_lib.h>
#include <timing_lib.h>
#include <rtc_driver.h>
#include <backlight_driver.h>
#include <dialog_lib.h>
#include <gfx_lib.h>
#include <memblock_lib.h>
#include <picture_lib.h>
#include <popup_lib.h>
#include <power_driver.h>
#include <uart_driver.h>

#include "flashpics.h"


#define SPLASH_SCREEN_SECONDS 3


TIMING_event_t joystickCallbackEvent;



#ifdef __GNUC__

char const CAL_PGM_DEF(welcomeTitle[]) = "AVR DB101 GCC ";

char const CAL_PGM_DEF(welcomeText[]) =
	"This is the gcc port"
	"of the demo appli-  "
	"cation for the DB101"
	"display kit. Ported "
	"by Martin Thomas    "
	"based on code from  "
	"Atmel for EWAVR. The"
	"port is preliminary."
	"Enjoy!              ";

#else

char const CAL_PGM_DEF(welcomeTitle[]) = "Atmel DB101 Demo";

char const CAL_PGM_DEF(welcomeText[]) =
	"Welcome to the demo "
	"application for the "
	"DB101 display kit.  "
	"Please refer to the "
	"appnotes AVR481 and "
	"AVR482 available at "
	"www.atmel.com/avr   "
	"for more details.   ";
#endif

#define APP_COUNT 12
char const CAL_PGM_DEF(appTitle[]) = "Choose application";
char const CAL_PGM_DEF(app0[]) = "Introduction";
char const CAL_PGM_DEF(app1[]) = "LCD Contrast";
char const CAL_PGM_DEF(app2[]) = "Smokey GFX Demo";
char const CAL_PGM_DEF(app3[]) = "Game of Life";
char const CAL_PGM_DEF(app4[]) = "Snake";
char const CAL_PGM_DEF(app5[]) = "Clock";
char const CAL_PGM_DEF(app6[]) = "Slideshow";
char const CAL_PGM_DEF(app7[]) = "Picture walkabout";
char const CAL_PGM_DEF(app8[]) = "Configure UART";
char const CAL_PGM_DEF(app9[]) = "Terminal emulator";
char const CAL_PGM_DEF(app10[]) = "Music demo";
char const CAL_PGM_DEF(app11[]) = "Power Save Mode";
char const CAL_PGM_DEF(* apps[APP_COUNT]) = { app0, app1, app2, app3, app4, app5, app6, app7, app8, app9, app10, app11 };
WIDGETS_StaticText_t textWidgets[APP_COUNT];


void InitMemory( void );

void SmokeyDemo( void );
void GameOfLife( void );
void Snake( void );
void Clock( void );
void Slideshow( void );
void Walkabout( void );
void ConfigUart( void );
void SoundDemo( void );
void Terminal( void );
void LcdContrast( void );


void UnknownError( void )
{
	POPUP_MsgBox( 14, 1, 10, "Unknown error!", NULL );
	for (;;) {}
}


/*** CUSTOM CODE FOR SCREEN DUMP TO USART1 ***/
static uint8_t lcdPageBuffer[LCD_WIDTH];
char const CAL_PGM_DEF(xpmHeader[]) =
		"/* XPM */\r\n"
		"static char * db101_screen_dump[] = {\r\n"
		"\"128 64 2 1\",\r\n"
		"\"   c #FFFFFF\",\r\n"
		"\".  c #000000\",\r\n";			
void DumpChar( char ch )
{
	do { /* nothing */ } while ((UCSR1A & (1 << UDRE1)) == 0);
	UDR1 = ch;
}
void DumpHeader( void )
{
	char const CAL_PGM(* pch) = xpmHeader;
	char ch;

	while ( ( ch = CAL_pgm_read_char( pch ) ) != '\0' ) {
		DumpChar( ch );
		pch++;
	}
}
void DumpScreen( void )
{
	PRR1 &= ~(1 << PRUSART1);
	UCSR1B |= (1 << TXEN1);
	UBRR1 = UART_CALC_UBRR_VALUE(115200);
	DDRD |= (1 << PD4); PORTD &= ~(1 << PD4); // Turn on RS232.
	DumpHeader();
	for (uint8_t row = 0; row < LCD_PAGE_COUNT; ++row) {
		LCD_ReadPage( lcdPageBuffer, LCD_ROW2PAGE(row), 0, LCD_WIDTH );
		for (uint8_t subrow = 0; subrow < LCD_PAGE_HEIGHT; ++subrow) {
			DumpChar( '"' );
			for (uint8_t column = 0; column < LCD_WIDTH; ++column) {
				if ((lcdPageBuffer[column] & (0x01 << subrow)) != 0x00) {
					DumpChar( '.' );
				} else {
					DumpChar( ' ' );
				}
			}
			DumpChar( '"' );
			DumpChar( '\r' );
			DumpChar( '\n' );
		}
	}
	DumpChar( '}' );
	DumpChar( ';' );
	DumpChar( '\r' );
	DumpChar( '\n' );
}	


CAL_MAIN()
{
	// Initialize everything.
	InitMemory();
	POWER_Init();
	LCD_Init();
	BACKLIGHT_Init();
	BACKLIGHT_SetRGB( 0, 0, 0 );
	TIMING_Init();
	RTC_Init();
	RTC_SetTickHandler( TIMING_TickHandler );
	JOYSTICK_Init( 100, 50 );
	TIMING_AddRepCallbackEvent( TIMING_INFINITE_REPEAT, 1, JOYSTICK_PollingHandler, &joystickCallbackEvent );

	CAL_enable_interrupt();

	// Display splash screen, wait for joystick.
	PICTURE_CopyFullscreenFlashToLcd( FLASHPICS_excellenceThroughTechnology );
	TIMING_event_t * splashScreenEvent = MEM_ALLOC( TIMING_event_t );
	if (splashScreenEvent == NULL) { UnknownError(); }
	TIMING_counter_t volatile splashCounter = 0;
	TIMING_AddCounterEventAfter( RTC_TICKS_PER_SECOND * SPLASH_SCREEN_SECONDS,
			&splashCounter, splashScreenEvent );
	bool exit = false;
	do {
		POWER_EnterIdleSleepMode();
		if (JOYSTICK_GetState() != 0x00) { exit = true; };
		if (splashCounter != 0) { exit = true; }
	} while (exit == false);
	TIMING_RemoveEvent( splashScreenEvent );
	MEM_FREE( splashScreenEvent );


	// Menu main loop.
	WIDGETS_id_t appId = 0;
	for (;;) {
		appId = DIALOG_SingleChoiceBox_F( appTitle, APP_COUNT, appId, apps, true, textWidgets );
		switch (appId) {
			case 0 :
				DIALOG_MessageBox_F( welcomeTitle, welcomeText, DIALOG_OK, DIALOG_OK, true );
			break;
			
			case 1 : LcdContrast(); break;
			case 2 : SmokeyDemo(); break;
			case 3 : GameOfLife(); break;
			case 4 : Snake(); break;
			case 5 : Clock(); break;
			case 6 : Slideshow(); break;
			case 7 : Walkabout(); break;
			case 8 : ConfigUart(); break;
			case 9 : Terminal(); break;
			case 10: SoundDemo(); break;
			
			case 11 :
				POPUP_MsgBox( 16, 4, 6,
						"Screen will go  "
						"blank. Move the "
						"joystick to wake"
						"up again.", NULL );
				JOYSTICK_PrepareForSleep();
				POWER_EnterPowerSaveMode();
			break;

			default :
				POPUP_MsgBox( 16, 2, 6, "Operation not\r\nimplemented yet.", NULL );
				DumpScreen();
			break;
		}
	}

	CAL_MAIN_LAST();
}
