/* template header file */
/* Copyright (C) 2010 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef CB_LIST_H
#define CB_LIST_H

#include <stdlib.h>


/*!\file
 * \ingroup geXPal_lib
 * \brief manage lists of callback functions
 */

/*!\brief callback function type
 */
typedef void (* cb_function_t)(void *);

/*! \brief Callback List entry type
 *
 *  The register function will dynamically create a new entry based on this type
 */
typedef struct cb_list_entry_s {
  /*! \brief pointer to next element or NULL if last element */
  struct cb_list_entry_s * next_entry;
  /*! \brief Function pointer to call */
  cb_function_t pTargetFkt;
  /*! \brief Argument to callback function */
  void * FktArg;
} cb_list_entry_t;

/*!\brief type pointer to a callback list
 */
typedef cb_list_entry_t *cb_list_t;

/*! \brief call all functions in callback list
 *
 * Iterates over all functions registered in list
 * \param list pointer to first item in list
 */
inline void callback_iterate (cb_list_t list)
{
  cb_list_entry_t * p;
  for (p = list; p; p = p->next_entry) {
    (*p->pTargetFkt) (p->FktArg);
  }
}


/*!\brief Register a call back function into the given list
 *
 * The function will add an entry to the list of functions to be called
 *
 * The new entry is added to the front of the list.
 *
 * \param list pointer to list variable
 * \param fkt2call function to be called
 * \param arg argument to give to fkt2call
 */
inline void cb_register_call(cb_list_t * list,
			     cb_function_t fkt2call, void *arg)
{
  cb_list_entry_t * n;

  // create new element
  n = malloc(sizeof(cb_list_entry_t));
  // link in current start element
  n->next_entry = *list;
  // initialize
  n->pTargetFkt = fkt2call;
  n->FktArg = arg;
	  
  // store new element into first
  *list = n;
}

#endif
