/* Header file for eXPal key scanning system */
/* Copyright (C) 2009 Thomas Klosa
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

/**
 * @file
 * @ingroup geXPal_lib
 * @brief  Key Scan and alphanumeric input machine header file
 */


#ifndef HL_KEYS_H
#define HL_KEYS_H


#include <avr/pgmspace.h>


/** @brief Empty KEYCODE*/
#define HL_NOKEY		0
/** @brief Key has been processed*/
#define HL_KEY_DONE		-1


/*!
\def BLD_SC(col, row, row_abc)
Merge the col, row and RowGroup to a 16bit scan code.
*/
#define BLD_SC(col, row, row_abc) ((_BV(col)<<8) | (_BV(row_abc)<<8) | _BV(row))  //!< \n

 
#define HL_SCAN_SOFT1		BLD_SC(HL_KEY_COL0,HL_KEY_ROW0,HL_KEY_ROW_A_ID) //!< Display SOFT1 - up left
#define HL_SCAN_SOFT2		BLD_SC(HL_KEY_COL0,HL_KEY_ROW1,HL_KEY_ROW_A_ID) //!< Display SOFT2
#define HL_SCAN_SOFT3		BLD_SC(HL_KEY_COL0,HL_KEY_ROW2,HL_KEY_ROW_A_ID) //!< Display SOFT3 - bottom left

#define HL_SCAN_SOFT4		BLD_SC(HL_KEY_COL0,HL_KEY_ROW3,HL_KEY_ROW_A_ID) //!< Display SOFT4 - below left
#define HL_SCAN_SOFT5		BLD_SC(HL_KEY_COL0,HL_KEY_ROW4,HL_KEY_ROW_B_ID) //!< Display SOFT5
#define HL_SCAN_SOFT6		BLD_SC(HL_KEY_COL0,HL_KEY_ROW5,HL_KEY_ROW_B_ID) //!< Display SOFT6
#define HL_SCAN_SOFT7		BLD_SC(HL_KEY_COL0,HL_KEY_ROW6,HL_KEY_ROW_B_ID) //!< Display SOFT7
#define HL_SCAN_SOFT8		BLD_SC(HL_KEY_COL0,HL_KEY_ROW7,HL_KEY_ROW_B_ID) //!< Display SOFT8 - below right

#define HL_SCAN_SOFT9		BLD_SC(HL_KEY_COL0,HL_KEY_ROW8,HL_KEY_ROW_B_ID) //!< Display SOFT9 - up right
#define HL_SCAN_SOFT10		BLD_SC(HL_KEY_COL0,HL_KEY_ROW9,HL_KEY_ROW_B_ID) //!< Display SOFT10
#define HL_SCAN_SOFT11		BLD_SC(HL_KEY_COL0,HL_KEY_ROW10,HL_KEY_ROW_B_ID)//!< Display SOFT11 - bottom right\n

#define HL_SCAN_LEFT1		BLD_SC(HL_KEY_COL2,HL_KEY_ROW0,HL_KEY_ROW_A_ID)	//!< Left Thumb - up left
#define HL_SCAN_LEFT2		BLD_SC(HL_KEY_COL2,HL_KEY_ROW1,HL_KEY_ROW_A_ID)	//!< Left Thumb
#define HL_SCAN_LEFT3		BLD_SC(HL_KEY_COL2,HL_KEY_ROW2,HL_KEY_ROW_A_ID)	//!< Left Thumb
#define HL_SCAN_LEFT4		BLD_SC(HL_KEY_COL2,HL_KEY_ROW3,HL_KEY_ROW_A_ID)	//!< Left Thumb - bottom right

#define HL_SCAN_RIGHT1		BLD_SC(HL_KEY_COL2,HL_KEY_ROW4,HL_KEY_ROW_B_ID)	//!< Right Thumb - up right
#define HL_SCAN_RIGHT2		BLD_SC(HL_KEY_COL2,HL_KEY_ROW5,HL_KEY_ROW_B_ID)	//!< Right Thumb
#define HL_SCAN_RIGHT3		BLD_SC(HL_KEY_COL2,HL_KEY_ROW6,HL_KEY_ROW_B_ID)	//!< Right Thumb
#define HL_SCAN_RIGHT4		BLD_SC(HL_KEY_COL2,HL_KEY_ROW7,HL_KEY_ROW_B_ID)	//!< Right Thumb - bottom left\n

#define HL_SCAN_NUM0		BLD_SC(HL_KEY_COL1,HL_KEY_ROW0,HL_KEY_ROW_A_ID)	//!< Number Area 0 - bottom center
#define HL_SCAN_NUM1		BLD_SC(HL_KEY_COL1,HL_KEY_ROW1,HL_KEY_ROW_A_ID)	//!< Number Area 1
#define HL_SCAN_NUM2		BLD_SC(HL_KEY_COL1,HL_KEY_ROW2,HL_KEY_ROW_A_ID)	//!< Number Area 2
#define HL_SCAN_NUM3		BLD_SC(HL_KEY_COL1,HL_KEY_ROW3,HL_KEY_ROW_A_ID)	//!< Number Area 3
#define HL_SCAN_NUM4		BLD_SC(HL_KEY_COL1,HL_KEY_ROW4,HL_KEY_ROW_B_ID)	//!< Number Area 4
#define HL_SCAN_NUM5		BLD_SC(HL_KEY_COL1,HL_KEY_ROW5,HL_KEY_ROW_B_ID)	//!< Number Area 5
#define HL_SCAN_NUM6		BLD_SC(HL_KEY_COL1,HL_KEY_ROW6,HL_KEY_ROW_B_ID)	//!< Number Area 6
#define HL_SCAN_NUM7		BLD_SC(HL_KEY_COL1,HL_KEY_ROW7,HL_KEY_ROW_B_ID)	//!< Number Area 7
#define HL_SCAN_NUM8		BLD_SC(HL_KEY_COL1,HL_KEY_ROW8,HL_KEY_ROW_B_ID)	//!< Number Area 8
#define HL_SCAN_NUM9		BLD_SC(HL_KEY_COL1,HL_KEY_ROW9,HL_KEY_ROW_B_ID)	//!< Number Area 9
#define HL_SCAN_STAR		BLD_SC(HL_KEY_COL1,HL_KEY_ROW10,HL_KEY_ROW_B_ID)	//!< Number Area *
#define HL_SCAN_POUND		BLD_SC(HL_KEY_COL1,HL_KEY_ROW11,HL_KEY_ROW_B_ID)	//!< Number Area #\n


/* MultiKey SplashScreen Bounding Box
*/
#define HL_KEYDIS_X		85	//!< Key Splash Position X
#define HL_KEYDIS_Y		0	//!< Key Splash Position Y
#define HL_KEYDIS_W		70	//!< Key Splash Width
#define HL_KEYDIS_H		15	//!< Key Splash Hight
#define HL_KEYDIS_FR_W	2	//!< Frame Width
#define HL_KEYDIS_TO_X	6	//!< Area to text offset X
#define HL_KEYDIS_TO_Y	4	//!< Area to text offset Y
#define HL_KEYDIS_FNT_W	8	//!< Font Width
#define HL_KEYDIS_FNT_H	8	//!< Font Hight\n

#define HL_KEYDIS_OFF	0
#define HL_KEYDIS_ON	1


/** @brief Single PushKeys >= 0x80
	All entered Characters < 0x80 are generated by a multi push key
 */
#define HL_KEY_MULTI	0x80

/* Starting left, anti clockwise */
#define HL_KEY_SOFT_1	0x80	//!< Soft1 return code
#define HL_KEY_SOFT_2	0x81	//!< Soft2 return code
#define HL_KEY_SOFT_3	0x82	//!< Soft3 return code
#define HL_KEY_SOFT_4	0x83	//!< Soft4 return code
#define HL_KEY_SOFT_5	0x84	//!< Soft5 return code
#define HL_KEY_SOFT_6	0x85	//!< Soft6 return code
#define HL_KEY_SOFT_7	0x86	//!< Soft7 return code
#define HL_KEY_SOFT_8	0x87	//!< Soft8 return code
#define HL_KEY_SOFT_9	0x88	//!< Soft9 return code
#define HL_KEY_SOFT_A	0x89	//!< Soft10 return code
#define HL_KEY_SOFT_B	0x8A	//!< Soft11 return code

/* left thumb keys, top to bottom */
#define HL_KEY_LEFT_1	0x90	//!< Left Thumb 1 return code
#define HL_KEY_LEFT_2	0x91	//!< Left Thumb 2 return code
#define HL_KEY_LEFT_3	0x92	//!< Left Thumb 3 return code
#define HL_KEY_LEFT_4	0x93	//!< Left Thumb 4 return code

/* right thumb keys, top to bottom */
#define HL_KEY_RIGHT_1	0x94	//!< Right Thumb 1 return code
#define HL_KEY_RIGHT_2	0x95	//!< Right Thumb 2 return code
#define HL_KEY_RIGHT_3	0x96	//!< Right Thumb 3 return code
#define HL_KEY_RIGHT_4	0x97	//!< Right Thumb 4 return code

/* Center key field results
	Multi push Keys <0x80
 */
#define HL_KEY_1	0x31	//!< MultiPush return code 1
#define HL_KEY_2	0x32	//!< MultiPush return code 2
#define HL_KEY_3	0x33	//!< MultiPush return code 3
#define HL_KEY_4	0x34	//!< MultiPush return code 4
#define HL_KEY_5	0x35	//!< MultiPush return code 5
#define HL_KEY_6	0x36	//!< MultiPush return code 6
#define HL_KEY_7	0x37	//!< MultiPush return code 7
#define HL_KEY_8	0x38	//!< MultiPush return code 8
#define HL_KEY_9	0x39	//!< MultiPush return code 9
#define HL_KEY_0	0x30	//!< MultiPush return code 0
#define HL_KEY_A	0x41	//!< MultiPush return code A
#define HL_KEY_B	0x42	//!< MultiPush return code B
#define HL_KEY_C	0x43	//!< MultiPush return code C
#define HL_KEY_D	0x44	//!< MultiPush return code D
#define HL_KEY_E	0x45	//!< MultiPush return code E
#define HL_KEY_F	0x46	//!< MultiPush return code F
#define HL_KEY_G	0x47	//!< MultiPush return code G
#define HL_KEY_H	0x48	//!< MultiPush return code H
#define HL_KEY_I	0x49	//!< MultiPush return code I
#define HL_KEY_J	0x4A	//!< MultiPush return code J
#define HL_KEY_K	0x4B	//!< MultiPush return code K
#define HL_KEY_L	0x4C	//!< MultiPush return code L
#define HL_KEY_M	0x4D	//!< MultiPush return code M
#define HL_KEY_N	0x4E	//!< MultiPush return code N
#define HL_KEY_O	0x4F	//!< MultiPush return code O
#define HL_KEY_P	0x50	//!< MultiPush return code P
#define HL_KEY_Q	0x51	//!< MultiPush return code Q
#define HL_KEY_R	0x52	//!< MultiPush return code R
#define HL_KEY_S	0x53	//!< MultiPush return code S
#define HL_KEY_T	0x54	//!< MultiPush return code T
#define HL_KEY_U	0x55	//!< MultiPush return code U
#define HL_KEY_V	0x56	//!< MultiPush return code V
#define HL_KEY_W	0x57	//!< MultiPush return code W
#define HL_KEY_X	0x58	//!< MultiPush return code X
#define HL_KEY_Y	0x59	//!< MultiPush return code Y
#define HL_KEY_Z	0x5A	//!< MultiPush return code Z
#define HL_KEY_STAR	0x2A	//!< MultiPush return code *
#define HL_KEY_POUND	0x23		//!< MultiPush return code #
#define HL_KEY_AE	196		//!< MultiPush return code 
#define HL_KEY_OE	214		//!< MultiPush return code 
#define HL_KEY_UE	220		//!< MultiPush return code 
#define HL_KEY_SZ	223		//!< MultiPush return code 
#define HL_KEY_DOT	0x2E	//!< MultiPush return code .
#define HL_KEY_KOMMA	0x2C	//!< MultiPush return code ,
#define HL_KEY_MINUS	0x2D	//!< MultiPush return code -
#define HL_KEY_PLUS		0x2B	//!< MultiPush return code +
#define HL_KEY_EQL		0x3D	//!< MultiPush return code =
#define HL_KEY_SLASH	0x5C	//!< MultiPush return code / \n


/* Key States */
#define HL_KEYSTATE_NOKEY	0		//!< Key State Code - idle 
#define HL_KEYSTATE_DEBOUNCE	1	//!< Key State Code - wait to stabilize state
#define HL_KEYSTATE_DOWN	2		//!< Key State Code - at least one key is down
#define HL_KEYSTATE_UP		3		//!< Key State Code - keys are up, waiting for multi push


/* Key Timing  */
#define HL_KEY_DEBOUNCE_CYCLES	2 	//!< Key recognized after n poll cycles
#define HL_KEY_WAIT_ALT_FKT		50	//!< wait for same key again, polls to keep splash screen open
#define HL_KEY_MAX_KEY_FUNCT	3   //!< maximum number of key codes per key

#define HL_KEY_BUFSZ	8			//!< size of key buffer

/*******************************************************************/
/* Function prototypes */

/** @brief Initialize key scan system
 *
 *	Must be called at program start, before hlKeyTmTick() is called for the first time
 */
void hl_Key_Init(void);


/** @brief Provide regular CPU time to the key scan engine
 *
 *	For ergonomic reasons, a calling interval of 20ms is a 
 *  good trade off in between fluid operation and CPU time consumption
 */
void hlKeyTmTick(void);	// key handling routine, must be called every 20ms


/** @brief  peek a key from the key buffer
 *
 * Get input keys from the character buffer
 *
 * @param[out] Key Pointer to store the key value 
 * @return returns number of keys in buffer or 0 if empty
 */
uint8_t hlGetKey(uint8_t *Key);	





#endif
