/* internal definitions for USARTS */
/* Copyright (C) 2010 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef USARTS_INT_H
#define USARTS_INT_H

#define UCSRnA(UC) (UC->base[0])
#define UCSRnB(UC) (UC->base[&UCSR0B-&UCSR0A])
#define UCSRnC(UC) (UC->base[&UCSR0C-&UCSR0A])
#define UBRRnL(UC) (UC->base[&UBRR0L-&UCSR0A])
#define UBRRnH(UC) (UC->base[&UBRR0H-&UCSR0A])
#define UBRRn(UC)  (*((volatile uint16_t *)(&UC->base[(volatile uint8_t*)&UBRR0-&UCSR0A])))
#define UDRn(UC)   (UC->base[&UDR0-&UCSR0A])

#define USART_DEF_CTRL(N) \
  static prog_char usart_name_##N[] = "USART"#N;			\
  usart_control_t usart_control_##N =					\
    { .name = usart_name_##N,						\
      .base = (uint8_t * const)&(UCSR##N##A),				\
      .prr = (N == 0 ? &PRR0 : &PRR1),					\
      .prusart = _BV(PRUSART##N),					\
    };

#define USART_DEF_RXINT(N)						\
  extern usart_control_t usart_control_##N;				\
  ISR(USART##N##_RX_vect,ISR_BLOCK)					\
  {									\
    usart_control_t * const uc = &usart_control_##N;			\
    /* loop until hardware RX buffer is empty - reduces INT load */	\
    /*    while (UCSRnA(uc) & _BV(RXC0)) {*/				\
    do {								\
      fifo_putQ_item (&uc->rxbuf, UDR##N);				\
    } while((UCSR##N##A & _BV(RXC##N)));				\
  }

#define USART_DEF_TXINT(N)						\
  extern usart_control_t usart_control_##N;				\
  /*ISR(USART##N##_TX_vect)						\
  {									\
    usart_control_t * const uc = &usart_control_##N;			\
  }*/									\
									\
  ISR(USART##N##_UDRE_vect,ISR_BLOCK)					\
  {									\
    usart_control_t * const uc = &usart_control_##N;			\
    if (!fifo_is_empty (&uc->txbuf)) {					\
      UDR##N = fifo_getQ_item (&uc->txbuf);				\
    } else {								\
      /* disable further interrupts (we have no data yet anyway) */	\
      UCSR##N##B &= ~_BV(UDRIE##N);					\
    }									\
  }

#endif
