/* ADC functions */
/* Copyright (C) 2009, 2010 Holger Dietze 
=======
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "adc.h"
#include <avr/io.h>
#include <avr/power.h>

void hl_adc_init (void)
{
  /* Start ADC Clock */
  power_adc_enable ();

  /* switch pin to input and disable Pull-Up resistor */
  DDRF &= ~_BV(DDF0);
  PORTF &= ~_BV(PF0);

  /* disable digital input on ADC7:0 */
  DIDR0 = _BV(ADC7D)|_BV(ADC6D)|_BV(ADC5D)|_BV(ADC4D)
    | _BV(ADC3D)|_BV(ADC2D)|_BV(ADC1D)|_BV(ADC0D);

  ADMUX = _BV(REFS1)|_BV(REFS0) /* 2.56 V as reference */
    | _BV(ADLAR) /* left adjust result */
    /* input: ADC0 SE*/
    | 0*_BV(MUX4)|0*_BV(MUX3)|0*_BV(MUX2)|0*_BV(MUX1)|0*_BV(MUX0);
  ADCSRB = 0*_BV(MUX5);

  ADCSRA = _BV(ADEN) /* enable ADC */
    | _BV(ADPS2)|_BV(ADPS1)|_BV(ADPS0); /* clock prescaler=256 */
}

/*
	Switch ADC off to save power
*/
void hl_adc_off (void){

  ADCSRA &= ~_BV(ADEN);	/* Disable ADC */
  PRR0 |= _BV(PRADC);	/* Stop ADC Clock */
}


//void hl_adc_off (void)
//{
  /* power-down ADC */
//  power_adc_disable ();
//}

void hl_adc_select (hl_adc_channel chan)
{
  uint8_t mux_l, mux_h;

  /* setup input MUX */
  switch (chan) {
  case adc_chan0:
    mux_l = 0;
    mux_h = 0;
    break;
  case adc_ref:
    mux_l = 0;
    mux_h = _BV(MUX4)|_BV(MUX3)|_BV(MUX2)|_BV(MUX1);
    break;
  default: return;
  }
  ADMUX = (ADMUX & ~(_BV(MUX4)|_BV(MUX3)|_BV(MUX2)|_BV(MUX1)|_BV(MUX0)))
    | mux_l;
  ADCSRB = (ADCSRB & ~_BV(MUX5)) | mux_h;
}

void hl_adc_start (void)
{
  /* start conversion */
  ADCSRA |= _BV(ADSC);
}

uint8_t hl_adc_isready (void)
{
#if 0
  return bit_is_clear(ADCSRA, ADSC);
#else
  return bit_is_set(ADCSRA, ADIF);
#endif
}

uint16_t hl_adc_result (void)
{
  uint16_t r = ADCW;
#if 1
  ADCSRA |= _BV(ADIF); /* reset pending INT */
#endif
  return r;
}
