/* display scroll implementation */
/* Copyright (C) 2009 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <stdint.h>
#include <string.h>

#include "display.h"
#include "lh155.h"

static inline void hl_lcd_transfer_line (uint8_t * buf, uint8_t write, uint8_t y) __attribute((__always_inline__));
static inline void hl_lcd_transfer_line (uint8_t * buf, uint8_t write, uint8_t y)
{
  uint8_t x;

  HL_LCD_SetX (0);
  HL_LCD_SetY (y);

  if (!write) HL_LCD_ReadData (); /* dummy read */
  for (x = 0; x < HL_LCD_WIDTH_BYTES; x++) {
    if (write)
      HL_LCD_WriteData (*buf++);
    else
      *buf++ = HL_LCD_ReadData ();
  }
}

static void hl_lcd_read_line (uint8_t * buf, uint8_t y)
{
  hl_lcd_transfer_line (buf, 0, y);
}

static void hl_lcd_write_line (uint8_t *buf, uint8_t y)
{
  hl_lcd_transfer_line (buf, 1, y);
}

void hl_lcd_scroll_up (uint8_t lines)
{
  uint8_t buf[HL_LCD_WIDTH_BYTES];
  uint8_t ldst, lsrc;

  /* prepare for linewise R/W */
  HL_LCD_WriteCmd (HL_LCD_INC_CTRL | HL_LCD_INC_CTRL_AXI);

  /* move display contents upwards */
  for (ldst = 0, lsrc = lines; lsrc < HL_LCD_HEIGHT; ldst++, lsrc++) {
    hl_lcd_read_line (buf, lsrc);
    hl_lcd_write_line (buf, ldst);
  }

  /* clear out rest of LCD */
  memset (buf, 0, sizeof (buf));
  for (;ldst < HL_LCD_HEIGHT; ldst++) {
    hl_lcd_write_line (buf, ldst);
  }

  /* back to no autoinc */
  HL_LCD_WriteCmd (HL_LCD_INC_CTRL);
}

