/* FIFO buffer implementation */
/* Copyright (C) 2009 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "fifo.h"
#include "rtc.h"

void fifo_init (fifo_t * f, fifo_item_t * buffer, fifo_size_t size)
{
  f->buffer = buffer;
  f->size = size;
  f->head = 0;
  f->tail = 0;
  f->num_items = 0;
  f->overflow = 0;
  f->underflow = 0;
}

fifo_item_t fifo_get_item (fifo_t * f)
{
  fifo_size_t tail;
  fifo_item_t data;
  uint8_t sreg;

  while (!f->num_items)
    hl_sleep_for_tick (0);

  tail = f->tail;
  
  data = f->buffer[tail++];
  if (tail == f->size) {
    tail = 0;
  }
  f->tail = tail;
  
  sreg = SREG;
  cli ();
  f->num_items--;
  SREG = sreg;

  return data;
}

