/* terminal implementation */
/* Copyright (C) 2009 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "term.h"
#include "lh155.h"
#include "display.h"

typedef struct term_status_s {
  uint8_t cursor_x;
  uint8_t cursor_y;
#ifdef FONT_CONST
  uint8_t font_width;
  uint8_t font_height;
#endif
} term_status_t;

static term_status_t myterm_status;

void term_init (void)
{
  myterm_status.cursor_x = myterm_status.cursor_y = 0;
#ifdef FONT_CONST
  myterm_status.font_width = hl_lcd_get_charwidth ();
  myterm_status.font_height = hl_lcd_get_charheight ();
#endif
}

void term_print (char c)
{
  term_status_t * t = &myterm_status;
  uint8_t w,h;
  switch (c) {
  case '\r':
    t->cursor_x = 0;
    return;
  case '\n':
  line_down:
    /* leave space for current line, too */
#ifdef FONT_CONST
    h = t->font_height;
#else
    h = hl_lcd_get_charheight ();
#endif
    if (t->cursor_y <= HL_LCD_HEIGHT - 2*h) {
      t->cursor_y += h;
      /* cursor_y + font_height <= HL_LCD_HEIGHT  is still valid */
      return;
    }
    hl_lcd_scroll_up (h);
    return;
  }
  /* normal char */
  hl_lcd_drawchar (t->cursor_x, t->cursor_y, c);
#ifdef FONT_CONST
  w = t->font_width;
#else
  w = hl_lcd_get_charwidth ();
#endif
  if (t->cursor_x <= HL_LCD_WIDTH - 2*w) {
    t->cursor_x += w;
    return;
  }
  /* wrap to next line */
  t->cursor_x = 0;
  goto line_down;
}

void term_strprint (const char * s)
{
  char c;
  while ((c = *s++)) {
    term_print (c);
  }
}

void term_strprint_P (PGM_P s)
{
  char c;
  while ((c = pgm_read_byte (s++))) {
    term_print (c);
  }
}
