/* USART access - send */
/* Copyright (C) 2010 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

/*!\file
 * \ingroup geXPal_lib
 * \brief generic USART access implementation - send
 */

#include "usarts.h"
#include "rtc.h"
#include "usarts_int.h"

#define USART_DEF USART_DEF_TXINT

#include "usarts_all.h"

void usart_send (usart_control_t * uc, uint8_t b)
{
  uint8_t was_empty;
  if (!(was_empty = fifo_is_empty (&uc->txbuf))) {
    while (!usart_can_send (uc))
      hl_sleep_for_tick (0);
  }

  fifo_put_uint8 (&uc->txbuf, b);
  if (was_empty) {
      /* enable further interrupts (we have data again) */
    UCSRnB(uc) |= _BV(UDRIE0);
  }
}
