/* USB fifo access */
/* Copyright (C) 2009 Thomas Klosa, Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <stdio.h>

#include "expal_board.h"
#include "hlog_extmem.h"

/**
@brief
    Add one character to UART0 tx ring. Sends a caret return sign if a newline character has been sent.
*/
static int
USBPutchar(char c, FILE *stream)
{
  /* check for connected USB port */
  if ( HL_USB_PWREN_PIN & _BV(HL_USB_PWREN)) {
    return -1;
  }
  if( (HL_USB_TXE_PIN & _BV(HL_USB_TXE)) == 0 ){
    
    *((char *)(HL_USB_BASE_ADR)) = c;		
    return 0;
    
  }else{		
    return -1;
  }
}


/**
@brief
    Receives one character via UART0.
*/
static int
USBGetchar(FILE *stream){
  
  /* Wait for data to be received */
  while ( (HL_USB_RXF_PIN & _BV(HL_USB_RXF)) != 0);
  
  /* Get and return received data from buffer */
  return *((char *)HL_USB_BASE_ADR);
  
}

/**
@brief
    Output stream associated with USB interface to use a vortual com port link.

@warning    
    To use standard I/O functions from <stdio.h> you have to assign its address to the standard
    stdout stream like this:
    
    stdout = [ampersand]USBStdout;
*/
static FILE USBStdout = FDEV_SETUP_STREAM( USBPutchar, NULL, _FDEV_SETUP_WRITE );

/**
@brief
    Input stream associated with USB.

@warning    
    To use standard I/O functions from <stdio.h> you have to assign its address to the standard
    stdout stream like this:
    
    stdin = [ampersand]USBStdin;
*/
static FILE USBStdin = FDEV_SETUP_STREAM( NULL, USBGetchar, _FDEV_SETUP_READ );
	
/**
@brief
    Initialises the USB Interface

@warning
    This function has to be sent before calling any standard I/O function.
*/
void
USBInit( void )  
{
  /* Init ExtMem Interface */
  ExtMemInit();
  
  /* Init USB specific signals */
  HL_USB_TXE_DDR   &= ~( _BV(HL_USB_TXE) ); // in
  HL_USB_RXF_DDR   &= ~( _BV(HL_USB_RXF) ); // in
  HL_USB_PWREN_DDR &= ~( _BV(HL_USB_PWREN) ); // in
  HL_USB_RESET_PORT |=  ( _BV(HL_USB_RESET) ); // high
  HL_USB_RESET_DDR |=  ( _BV(HL_USB_RESET) ); // out
  
  /* Reset USB Controller */
  // HL_USB_RESET_PORT &= ~( _BV(HL_USB_RESET) ); // low
  // HL_USB_RESET_PORT |=  ( _BV(HL_USB_RESET) ); // high
}


void
USB_assign_stdio (void)
{
  stdout = &USBStdout;
  stdin = &USBStdin;
}
