/* template header file */
/* Copyright (C) 2010 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef NMEA_HL_H
#define NMEA_HL_H

#include <stdint.h>

/*!\file
 * \ingroup geXPal_lib
 *
 *
 */

/*!\brief forward declaration for NMEA parser instance */
typedef struct nmea_parser_s  nmea_parser_t;

/*!\brief create a new NMEA parser instance
 */
nmea_parser_t * new_nmea_parser (void);

/*!\brief store data for one satellite
 */
typedef struct nmea_sat_s {
  uint8_t id; /*!<\brief satellite ID (1-32) */
  uint8_t elevation; /*!<\brief elevation of satellite (0-90) */
  uint16_t azimuth; /*!<\brief azimuth of satellite (0-359) */
  uint8_t snr; /*!<\brief SNR for satellite (0-99) */
} nmea_sat_t;

/*!\brief maximum number of satellites to allocate in data
 */
#define MAX_NUM_SATS (12)

/*!\brief return status for nmea_recvd()
 */
typedef enum {
  NMEA_LINE_MORE = 0, /*!< line is not complete yet */
  NMEA_LINE_CKERR,    /*!< checksum error */
  NMEA_LINE_OVERFLOW, /*!< too many characters for buffer */
  NMEA_LINE_OK,       /*!< line OK */
  NMEA_LINE_FIX,      /*!< position fix */
  NMEA_LINE_SAT,      /*!< SAT info */
} nmea_line_status_t;

/*!\brief give one character to NMEA parser
 *
 * \return information about last received line (if any)
 */
nmea_line_status_t nmea_recvd (nmea_parser_t *, char);

/*!\brief format current position for output
 */
int nmea_format_position (char * buf, size_t sz, nmea_parser_t * parser);

/*!\brief return reception status for one satellite
 *
 * \param parser
 * \param idx index of satellite to get status for
 * \return pointer to satellite status, NULL if idx is invalid
 */
nmea_sat_t * nmea_get_satellite (nmea_parser_t *parser, uint8_t idx);

#endif
