/* CRC7 implementation */
/* Copyright (C) 2009 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef CRC7_H
#define CRC7_H

/*!
 * \file crc7.h
 * implement CRC-7 as used in SD-Card command packets
 */

#include <stdint.h>

/*!
 * \brief CRC-7 calculation as used in SD-Card command packets
 *
 * \param crc  calculated CRC from bytes read so far (or 0 for first byte)
 * \param data byte to put into CRC
 * \return CRC-7 in lower 7 bits
 */
static inline uint8_t _crc7_update (uint8_t crc, uint8_t data)
{
#if 0
  int i;
  for (i = 8; i > 0; i--) {
    uint8_t b = (data >> 7) ^ ((crc & 0x40) >> 6);
    crc = (crc << 1) ^ b ^ (b << 3);
    crc &= 0x7f;
    data <<= 1;
  }
  return crc;
#else
  /* no need to do &= 0x7f, as that bit will not be used anyway */
  /*crc &= 0x7f;*/
  data ^= crc << 1;
  crc = data >> 4;
  data ^= crc ^ (crc >> 3);
  return /*0x7f & */((data) ^ (data << 3));
#endif
}


#endif
