/* main file for house number prototype */
/* Copyright (C) 2009 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/sleep.h>
#include <avr/pgmspace.h>

#include "lcd-displaytech.h"
#include "protoserial.h"

#include "protoconfig.h"
#include <util/delay.h>
#include "protostatus.h"

#define DO_SLEEP

volatile extern uint8_t serial_byte;

#if 0
int main (void) __attribute__ ((noreturn));
#endif

PROGMEM char startmessage[] = "Hello World";

int
main (void)
{
  prog_char * s;
  uint8_t b, x;
  
  /* explicitly disable JTAG */
  x = MCUCR | _BV(JTD);
  MCUCR = x;
  MCUCR = x; /* need to set it a second time within four cycles */

  DDRB = 0xff;
  proto_status (1, STATUS_CONT);

  lcd_disp_init ();
  serial_init (9600);

  x = 0x01;
  for (s = startmessage; (b = pgm_read_byte(s)); s++) {
    lcd_put_char (b);
    _delay_ms(100);
    proto_status( x = (x << 1) | (x >> 5), STATUS_CONT);
  }

  x |= (x << 4) | (x >> 4);

  for (b=0; b<40; b++) {
    _delay_ms(250);
    proto_status (x = (x >> 1) | (x << 5), STATUS_CONT);
  }

  /* LCD display does not work in power-down and standby modes */
#ifdef DO_SLEEP
  set_sleep_mode (SLEEP_MODE_PWR_SAVE);
#endif
  while (1) { /* event loop */
    uint8_t b;
    while ((b = serial_byte)) {
      serial_byte = 0;
      sei ();
      switch (b) {
      case '\r':
	lcd_home ();
	break;
      case '\n':
	break;
      default:
	lcd_put_char (b);
	break;
      }
      cli ();
    }
#ifdef DO_SLEEP
    sleep_enable ();
#endif
    sei ();
#ifdef DO_SLEEP
    sleep_cpu ();
    sleep_disable ();
#endif
  }

  return 0; /* to silence gcc warning */
}
