/* serial communications routines for prototype */
/* Copyright (C) 2009 Holger Dietze
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <avr/io.h>
#include <avr/interrupt.h>

#include "protoconfig.h"
#include "protoserial.h"

#define BAUD_TOL (1)
static const struct serial_param_s {
  uint16_t baud;
  uint16_t rate;
  uint8_t use_2x;
} serial_param[] = {
#include "baud-params.h"
  {0, 0, 0} /* END MARKER */
};

volatile uint8_t serial_byte;

void
serial_init (uint16_t speed)
{
  const struct serial_param_s *p;

  for (p = serial_param; p->baud && (p->baud != speed); p++);

  if (p->baud) {
    UBRRH = p->rate >> 8;
    UBRRL = p->rate & 0xff;
    if (p->use_2x)
      UCSRA |= _BV(U2X);
    else
      UCSRA &= ~_BV(U2X);

    /* enable receiver and RX interrupt */
    UCSRB = _BV(RXCIE) | _BV(RXEN) | _BV(RXEN);
    /* frame format: 8N1 */
    UCSRC = _BV(UCSZ1) | _BV(UCSZ0);
  }
}

ISR(USART_RXC_vect)
{
  PORTB ^= 0x02;
  if (UCSRA & _BV(RXC))
    serial_byte = (UDR);
}
